@@ -5,13 +5,10 @@
 
 """Implementation of gas rm."""
 
-import sys
 from typing import Dict
 
-import click
-
 from .tbrn import TBRN, TBRNType
-from .utility import get_dataset_client, get_gas
+from .utility import error, get_dataset_client, get_gas
 
 
 def _implement_rm(obj: Dict[str, str], tbrn: str, is_recursive: bool) -> None:
@@ -20,19 +17,15 @@ def _implement_rm(obj: Dict[str, str], tbrn: str, is_recursive: bool) -> None:
     dataset_client = get_dataset_client(gas, info, is_fusion=False)
 
     if info.type not in (TBRNType.SEGMENT, TBRNType.NORMAL_FILE):
-        click.echo(f'"{tbrn}" is an invalid path to remove', err=True)
-        sys.exit(1)
+        error(f'"{tbrn}" is an invalid path to remove')
 
     if not info.is_draft:
-        click.echo(
-            f'To remove the data, "{info}" must be in draft status, like "{info}#1"', err=True
-        )
-        sys.exit(1)
+        error(f'To remove the data, "{info}" must be in draft status, like "{info}#1"')
 
     if info.type == TBRNType.SEGMENT:
         if not is_recursive:
-            click.echo("Please use -r option to remove the whole segment", err=True)
-            sys.exit(1)
+            error("Please use -r option to remove the whole segment")
+
         dataset_client.delete_segment(info.segment_name)
         return
 
