@@ -17,7 +17,7 @@ It refers to the `Json schema`_ method to describe an attribute.
 from enum import Enum
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, TypeVar, Union
 
-from ..utility import EqMixin, NameMixin, ReprMixin, common_loads
+from ..utility import EqMixin, NameMixin, ReprMixin, attr, attr_base, camel, common_loads
 
 _AvailaleType = Union[list, bool, int, float, str, None]
 _SingleArgType = Union[str, None, Type[_AvailaleType]]
@@ -69,6 +69,9 @@ class Items(ReprMixin, EqMixin):
     When the value type of an attribute is array,
     the :class:`AttributeInfo` would contain an 'items' field.
 
+    .. todo::
+        The format of argument *type_* on the generated web page is incorrect.
+
     Arguments:
         type_: The type of the attribute value, could be a single type or multi-types.
             The type must be within the followings:
@@ -94,8 +97,8 @@ class Items(ReprMixin, EqMixin):
         items: The items inside array type attributes.
 
     Raises:
-        TypeError: When both enum and type_ are absent or
-            when type_ is array and items is absent.
+        TypeError: When both ``enum`` and ``type_`` are absent or
+            when ``type_`` is array and ``items`` is absent.
 
     Examples:
         >>> Items(type_="integer", enum=[1, 2, 3, 4, 5], minimum=1, maximum=5)
@@ -113,7 +116,7 @@ class Items(ReprMixin, EqMixin):
     _repr_attrs: Tuple[str, ...] = ("type", "enum", "minimum", "maximum", "items")
 
     def __init__(
-        self: _T,
+        self,
         *,
         type_: _ArgType = "",
         enum: Optional[Iterable[_EnumElementType]] = None,
@@ -226,6 +229,9 @@ class AttributeInfo(NameMixin, Items):
 
     It refers to the `Json schema`_ method to describe an attribute.
 
+    .. todo::
+        The format of argument *type_* on the generated web page is incorrect.
+
     Arguments:
         name: The name of the attribute.
         type_: The type of the attribute value, could be a single type or multi-types.
@@ -300,6 +306,9 @@ class AttributeInfo(NameMixin, Items):
     _repr_attrs = ("name", "parent_categories") + Items._repr_attrs
     _repr_maxlevel = 2
 
+    _attrs_base: Items = attr_base(key=None)
+    parent_categories: List[str] = attr(is_dynamic=True, key=camel)
+
     def __init__(
         self,
         name: str,
@@ -310,7 +319,7 @@ class AttributeInfo(NameMixin, Items):
         maximum: Optional[float] = None,
         items: Optional[Items] = None,
         parent_categories: Union[None, str, Iterable[str]] = None,
-        description: Optional[str] = None,
+        description: str = "",
     ):
         NameMixin.__init__(self, name, description)
         Items.__init__(self, type_=type_, enum=enum, minimum=minimum, maximum=maximum, items=items)
@@ -323,13 +332,6 @@ class AttributeInfo(NameMixin, Items):
         else:
             self.parent_categories = list(parent_categories)
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        NameMixin._loads(self, contents)
-        Items._loads(self, contents)
-
-        if "parentCategories" in contents:
-            self.parent_categories = contents["parentCategories"]
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Load an AttributeInfo from a dict containing the attribute information.
@@ -408,10 +410,4 @@ class AttributeInfo(NameMixin, Items):
             }
 
         """
-        contents: Dict[str, Any] = NameMixin._dumps(self)
-        contents.update(Items.dumps(self))
-
-        if hasattr(self, "parent_categories"):
-            contents["parentCategories"] = self.parent_categories
-
-        return contents
+        return self._dumps()
