@@ -32,14 +32,12 @@ produces strong visual distortion intended to create a wide panoramic or hemisph
 
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, TypeVar, Union
 
-from sortedcontainers import SortedDict
-
 from ..geometry import Transform3D
 from ..utility import (
     MatrixType,
     NameMixin,
-    NameSortedDict,
     ReprType,
+    SortedNameList,
     TypeEnum,
     TypeMixin,
     TypeRegister,
@@ -153,7 +151,7 @@ class Sensor(NameMixin, TypeMixin[SensorType]):
             Lidar("Lidar1")(
                 (extrinsics): Transform3D(
                     (translation): Vector3D(1.1, 2.2, 3.3),
-                    (rotation): Quaternion(1.1, 2.2, 3.3, 4.4)
+                    (rotation): quaternion(1.1, 2.2, 3.3, 4.4)
                 )
             )
 
@@ -206,7 +204,7 @@ class Sensor(NameMixin, TypeMixin[SensorType]):
             Lidar("Lidar1")(
                 (extrinsics): Transform3D(
                     (translation): Vector3D(1, 2, 3),
-                    (rotation): Quaternion(1, 2, 3, 4)
+                    (rotation): quaternion(1, 2, 3, 4)
                 )
             )
 
@@ -248,7 +246,7 @@ class Sensor(NameMixin, TypeMixin[SensorType]):
             Lidar("Lidar1")(
                 (extrinsics): Transform3D(
                     ...
-                    (rotation): Quaternion(2, 3, 4, 5)
+                    (rotation): quaternion(2, 3, 4, 5)
                 )
             )
 
@@ -272,7 +270,7 @@ class Lidar(Sensor):
         Lidar("Lidar1")(
             (extrinsics): Transform3D(
                 (translation): Vector3D(1, 2, 3),
-                (rotation): Quaternion(1, 2, 3, 4)
+                (rotation): quaternion(1, 2, 3, 4)
             )
         )
 
@@ -293,7 +291,7 @@ class Radar(Sensor):
         Radar("Radar1")(
             (extrinsics): Transform3D(
                 (translation): Vector3D(1, 2, 3),
-                (rotation): Quaternion(1, 2, 3, 4)
+                (rotation): quaternion(1, 2, 3, 4)
             )
         )
 
@@ -384,7 +382,7 @@ class Camera(Sensor):
             Camera("Camera1")(
                     (extrinsics): Transform3D(
                         (translation): Vector3D(1, 2, 3),
-                        (rotation): Quaternion(1, 2, 3, 4)
+                        (rotation): quaternion(1, 2, 3, 4)
                     ),
                     (intrinsics): CameraIntrinsics(
                         (camera_matrix): CameraMatrix(
@@ -525,20 +523,21 @@ class FisheyeCamera(Camera):  # pylint: disable=too-many-ancestors
         FisheyeCamera("FisheyeCamera1")(
             (extrinsics): Transform3D(
                 (translation): Vector3D(1, 2, 3),
-                (rotation): Quaternion(1, 2, 3, 4)
+                (rotation): quaternion(1, 2, 3, 4)
             )
         )
 
     """
 
 
-class Sensors(NameSortedDict[Sensor._Type]):  # pylint: disable=protected-access
+class Sensors(SortedNameList[Sensor._Type]):  # pylint: disable=protected-access
     """This class represents all sensors in a :class:`~tensorbay.dataset.segment.FusionSegment`."""
 
     _T = TypeVar("_T", bound="Sensors")
 
     def _loads(self, contents: List[Dict[str, Any]]) -> None:
-        self._data = SortedDict()
+        self._data = []
+        self._names = []
         for sensor_info in contents:
             self.add(Sensor.loads(sensor_info))
 
@@ -639,4 +638,4 @@ class Sensors(NameSortedDict[Sensor._Type]):  # pylint: disable=protected-access
                 ]
 
         """
-        return [sensor.dumps() for sensor in self._data.values()]
+        return [sensor.dumps() for sensor in self._data]
