@@ -16,7 +16,7 @@ from .common import (
     common_loads,
     locked,
 )
-from .name import NamedList, NameMixin, NameSortedDict, NameSortedList
+from .name import NameList, NameMixin, SortedNameList
 from .repr import ReprMixin, ReprType, repr_config
 from .type import SubcatalogTypeRegister, TypeEnum, TypeMixin, TypeRegister
 from .user import UserMapping, UserMutableMapping, UserMutableSequence, UserSequence
@@ -29,12 +29,11 @@ __all__ = [
     "Disable",
     "KwargsDeprecated",
     "MatrixType",
+    "NameList",
     "NameMixin",
-    "NameSortedDict",
-    "NameSortedList",
-    "NamedList",
     "ReprMixin",
     "ReprType",
+    "SortedNameList",
     "SubcatalogTypeRegister",
     "TypeEnum",
     "TypeMixin",
