@@ -16,7 +16,6 @@ from typing import (
     Callable,
     Dict,
     List,
-    NoReturn,
     Optional,
     Sequence,
     Tuple,
@@ -25,7 +24,7 @@ from typing import (
     no_type_check,
 )
 
-from typing_extensions import Protocol
+from typing_extensions import NoReturn, Protocol
 
 from ..exception import AttrError
 
@@ -297,7 +296,7 @@ def _get_operators(annotation: Any) -> Tuple[_Callable, _Callable]:
      AttrsMixin has three operating types which are classified by attr annotation.
         1. builtin types, like str, int, None
         2. tensorbay custom class, like tensorbay.label.Classification
-        3. tensorbay custom class list or NamedList, like List[tensorbay.label.LabeledBox2D]
+        3. tensorbay custom class list or NameList, like List[tensorbay.label.LabeledBox2D]
 
     Arguments:
         annotation: Type of the attr.
